==> apache-ignite-2.8.0-src.zip: apache-ignite-2.8.0-src/modules/core/src/main/java/org/apache/ignite/internal/processors/cache/persistence/RootPage.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.ignite.internal.processors.cache.persistence;

import org.apache.ignite.internal.pagemem.FullPageId;
import org.apache.ignite.internal.util.tostring.GridToStringInclude;
import org.apache.ignite.internal.util.typedef.internal.S;

/**
 *
 */
public class RootPage {
    /** */
    @GridToStringInclude
    private FullPageId pageId;

    /** */
    private boolean allocated;

    /**
     * @param pageId Page ID.
     * @param allocated {@code True} if was allocated new page.
     */
    public RootPage(final FullPageId pageId, final boolean allocated) {
        this.pageId = pageId;
        this.allocated = allocated;
    }

    /**
     * @return Page ID.
     */
    public FullPageId pageId() {
        return pageId;
    }

    /**
     * @return {@code True} if was allocated.
     */
    public boolean isAllocated() {
        return allocated;
    }

    /** {@inheritDoc} */
    @Override public String toString() {
        return S.toString(RootPage.class, this);
    }
}

==> apache-ignite-2.17.0-src.zip: apache-ignite-2.17.0-src/modules/core/src/main/java/org/apache/ignite/internal/processors/cache/persistence/RootPage.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.ignite.internal.processors.cache.persistence;

import org.apache.ignite.internal.pagemem.FullPageId;
import org.apache.ignite.internal.util.tostring.GridToStringInclude;
import org.apache.ignite.internal.util.typedef.internal.S;

/**
 *
 */
public class RootPage {
    /** */
    @GridToStringInclude
    private final FullPageId pageId;

    /** */
    private final boolean allocated;

    /**
     * @param pageId Page ID.
     * @param allocated {@code True} if was allocated new page.
     */
    public RootPage(final FullPageId pageId, final boolean allocated) {
        this.pageId = pageId;
        this.allocated = allocated;
    }

    /**
     * @return Page ID.
     */
    public FullPageId pageId() {
        return pageId;
    }

    /**
     * @return {@code True} if was allocated.
     */
    public boolean isAllocated() {
        return allocated;
    }

    /** {@inheritDoc} */
    @Override public String toString() {
        return S.toString(RootPage.class, this);
    }
}
